@@ -8,6 +8,8 @@ import re
 import matplotlib.pyplot as plt
 from discord_webhook import DiscordWebhook
 from difflib import Differ
+import requests
+import textfsm
 
 class Main():
 
@@ -38,7 +40,6 @@ class Main():
         self.SSHConnection = ConnectHandler(**self.SSH_data)
         print ("Connected to", self.host)
     
-
     def validate_is_string(self, inp):
         if type(inp) != str:
             raise ValueError ("Input is Not String. Check device parameters")
@@ -187,7 +188,7 @@ class Vyos(Main):  # Vyos/EdgeOS specific commands
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         # calls the __init__ method from the MAIN superclass, creating the netmiko SSH tunnel
-    
+
     def single_command(self, command):
         return (self.SSHConnection.send_command(command))
 
@@ -220,8 +221,14 @@ class Vyos(Main):  # Vyos/EdgeOS specific commands
     def get_ospf_neighbors(self):
         return (self.SSHConnection.send_command("show ip ospf neighbor"))
 
-    def get_bgp_neighbors(self):
-        return (self.SSHConnection.send_command("show ip bgp summary"))
+    def get_bgp_summary(self):
+        raw = (self.SSHConnection.send_command("show ip bgp summary"))
+
+        with open('vyosbgp.template.py') as template:
+            fsm = textfsm.TextFSM(template)
+            result = fsm.ParseText(raw)
+        
+        return result
 
     def get_interfaces(self):
         """Gets all interfaces on the device, including type, name, status, and description"""
